/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2007-2013 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.arrays;

/**
 * <p>Service interface for {@link ArraysSubMatrixImpl} class.</p>
 *
 * <p>AlgART Laboratory 2007-2013</p>
 *
 * @author Daniel Alievsky
 * @version 1.2
 * @since JDK 1.5
 */
interface ArraysSubMatrixIndexer {
    public boolean bitsBlocksImplemented();

    public boolean indexOfImplemented();

    public long translate(long index);

    public void getData(long arrayPos, Object destArray, int destArrayOffset, int count);

    public void setData(long arrayPos, Object srcArray, int srcArrayOffset, int count);

    public void getBits(long arrayPos, long[] destArray, long destArrayOffset, long count);

    public void setBits(long arrayPos, long[] srcArray, long srcArrayOffset, long count);

    //[[Repeat() Bit ==> Char,,Byte,,Short,,Int,,Long,,Float,,Double,,Object;;
    //           boolean(?=\s+value) ==> char,,byte,,short,,int,,long,,float,,double,,Object]]
    public long indexOfBit(long lowIndex, long highIndex, boolean value);

    public long lastIndexOfBit(long lowIndex, long highIndex, boolean value);

    public void fillBits(long position, long count, boolean value);

    //[[Repeat.AutoGeneratedStart !! Auto-generated: NOT EDIT !! ]]
    public long indexOfChar(long lowIndex, long highIndex, char value);

    public long lastIndexOfChar(long lowIndex, long highIndex, char value);

    public void fillChars(long position, long count, char value);

    public long indexOfByte(long lowIndex, long highIndex, byte value);

    public long lastIndexOfByte(long lowIndex, long highIndex, byte value);

    public void fillBytes(long position, long count, byte value);

    public long indexOfShort(long lowIndex, long highIndex, short value);

    public long lastIndexOfShort(long lowIndex, long highIndex, short value);

    public void fillShorts(long position, long count, short value);

    public long indexOfInt(long lowIndex, long highIndex, int value);

    public long lastIndexOfInt(long lowIndex, long highIndex, int value);

    public void fillInts(long position, long count, int value);

    public long indexOfLong(long lowIndex, long highIndex, long value);

    public long lastIndexOfLong(long lowIndex, long highIndex, long value);

    public void fillLongs(long position, long count, long value);

    public long indexOfFloat(long lowIndex, long highIndex, float value);

    public long lastIndexOfFloat(long lowIndex, long highIndex, float value);

    public void fillFloats(long position, long count, float value);

    public long indexOfDouble(long lowIndex, long highIndex, double value);

    public long lastIndexOfDouble(long lowIndex, long highIndex, double value);

    public void fillDoubles(long position, long count, double value);

    public long indexOfObject(long lowIndex, long highIndex, Object value);

    public long lastIndexOfObject(long lowIndex, long highIndex, Object value);

    public void fillObjects(long position, long count, Object value);

    //[[Repeat.AutoGeneratedEnd]]
}
